@@ -110,7 +110,7 @@ if __name__ == '__main__':
     from appzoo import App
 
     app = App(verbose=os.environ.get('verbose'))
-    app.add_route('/nh_bert/strict', predict_strict, method="POST")
-    app.add_route('/nh_bert/nostrict', predict_nostrict, method="POST")
+    app.add_route('/nh/strict', predict_strict, method="POST")
+    app.add_route('/nh/nostrict', predict_nostrict, method="POST")
 
     app.run(port=8000, access_log=False)
